satsim package
==============

.. automodule:: satsim
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   satsim.dataset
   satsim.generator
   satsim.geometry
   satsim.image
   satsim.io
   satsim.math
   satsim.pipeline
   satsim.radar
   satsim.tfa
   satsim.time
   satsim.util
   satsim.vecmath

Submodules
----------

satsim.cli module
-----------------

.. automodule:: satsim.cli
   :members:
   :undoc-members:
   :show-inheritance:

satsim.config module
--------------------

.. automodule:: satsim.config
   :members:
   :undoc-members:
   :show-inheritance:

satsim.satsim module
--------------------

.. automodule:: satsim.satsim
   :members:
   :undoc-members:
   :show-inheritance:
